@@ -32,11 +32,15 @@ where
             for mut bundle in bundles {
                 bundle.module = self.optimize(bundle.module);
 
-                bundle.module = bundle.module.fold_with(&mut hygiene());
+                if !self.config.disable_hygiene {
+                    bundle.module = bundle.module.fold_with(&mut hygiene());
+                }
 
                 bundle.module = self.may_wrap_with_iife(bundle.module);
 
-                bundle.module = bundle.module.fold_with(&mut fixer(None));
+                if !self.config.disable_fixer {
+                    bundle.module = bundle.module.fold_with(&mut fixer(None));
+                }
 
                 {
                     // Inject swc helpers
